@@ -1,8 +1,8 @@
+import collections
 from typing import Any, Dict, List
 
 import pandas as pd
 
-from bigtree import DAGNode
 from bigtree.node.node import Node
 from bigtree.tree.search import find_name
 from bigtree.utils.iterators import preorder_iter
@@ -10,11 +10,10 @@ from bigtree.utils.iterators import preorder_iter
 __all__ = [
     "print_tree",
     "yield_tree",
-    "tree_to_dataframe",
     "tree_to_dict",
     "tree_to_nested_dict",
+    "tree_to_dataframe",
     "tree_to_dot",
-    "dag_to_dot",
 ]
 
 
@@ -343,94 +342,6 @@ def yield_tree(
         yield pre_str, fill_str, _node
 
 
-def tree_to_dataframe(
-    tree: Node,
-    path_col: str = "path",
-    name_col: str = "name",
-    parent_col: str = "",
-    attr_dict: dict = {},
-    all_attrs: bool = False,
-    max_depth: int = None,
-    skip_depth: int = None,
-    leaf_only: bool = False,
-) -> pd.DataFrame:
-    """Export tree to pandas DataFrame.
-
-    All descendants from `tree` will be exported, `tree` can be the root node or child node of tree.
-
-    >>> from bigtree import Node, tree_to_dataframe
-    >>> root = Node("a", age=90)
-    >>> b = Node("b", age=65, parent=root)
-    >>> c = Node("c", age=60, parent=root)
-    >>> d = Node("d", age=40, parent=b)
-    >>> e = Node("e", age=35, parent=b)
-    >>> tree_to_dataframe(root, name_col="name", parent_col="parent", path_col="path", attr_dict={"age": "person age"})
-         path name parent  person age
-    0      /a    a   None          90
-    1    /a/b    b      a          65
-    2  /a/b/d    d      b          40
-    3  /a/b/e    e      b          35
-    4    /a/c    c      a          60
-
-
-    For a subset of a tree.
-
-    >>> tree_to_dataframe(b, name_col="name", parent_col="parent", path_col="path", attr_dict={"age": "person age"})
-         path name parent  person age
-    0    /a/b    b      a          65
-    1  /a/b/d    d      b          40
-    2  /a/b/e    e      b          35
-
-    Args:
-        tree (Node): tree to be exported
-        path_col (str): column name for `node.path_name`, optional
-        name_col (str): column name for `node.node_name`, defaults to 'name'
-        parent_col (str): column name for `node.parent.node_name`, optional
-        attr_dict (dict): dictionary mapping node attributes to column name,
-            key: node attributes, value: corresponding column in dataframe, optional
-        all_attrs (bool): indicator whether to retrieve all `Node` attributes
-        max_depth (int): maximum depth to export tree, optional
-        skip_depth (int): number of initial depth to skip, optional
-        leaf_only (bool): indicator to retrieve only information from leaf nodes
-
-    Returns:
-        (pd.DataFrame)
-    """
-    tree = tree.copy()
-    data_list = []
-
-    def recursive_append(node):
-        if (
-            (not max_depth or node.depth <= max_depth)
-            and (not skip_depth or node.depth > skip_depth)
-            and (not leaf_only or node.is_leaf)
-        ):
-            data_child = {}
-            if path_col:
-                data_child[path_col] = node.path_name
-            if name_col:
-                data_child[name_col] = node.node_name
-            if parent_col:
-                parent_name = None
-                if node.parent:
-                    parent_name = node.parent.node_name
-                data_child[parent_col] = parent_name
-
-            if all_attrs:
-                data_child.update(
-                    node.describe(exclude_attributes=["name"], exclude_prefix="_")
-                )
-            else:
-                for k, v in attr_dict.items():
-                    data_child[v] = node.get_attr(k)
-            data_list.append(data_child)
-        for _node in node.children:
-            recursive_append(_node)
-
-    recursive_append(tree)
-    return pd.DataFrame(data_list)
-
-
 def tree_to_dict(
     tree: Node,
     name_key: str = "name",
@@ -567,15 +478,105 @@ def tree_to_nested_dict(
     return data_dict[child_key][0]
 
 
+def tree_to_dataframe(
+    tree: Node,
+    path_col: str = "path",
+    name_col: str = "name",
+    parent_col: str = "",
+    attr_dict: dict = {},
+    all_attrs: bool = False,
+    max_depth: int = None,
+    skip_depth: int = None,
+    leaf_only: bool = False,
+) -> pd.DataFrame:
+    """Export tree to pandas DataFrame.
+
+    All descendants from `tree` will be exported, `tree` can be the root node or child node of tree.
+
+    >>> from bigtree import Node, tree_to_dataframe
+    >>> root = Node("a", age=90)
+    >>> b = Node("b", age=65, parent=root)
+    >>> c = Node("c", age=60, parent=root)
+    >>> d = Node("d", age=40, parent=b)
+    >>> e = Node("e", age=35, parent=b)
+    >>> tree_to_dataframe(root, name_col="name", parent_col="parent", path_col="path", attr_dict={"age": "person age"})
+         path name parent  person age
+    0      /a    a   None          90
+    1    /a/b    b      a          65
+    2  /a/b/d    d      b          40
+    3  /a/b/e    e      b          35
+    4    /a/c    c      a          60
+
+
+    For a subset of a tree.
+
+    >>> tree_to_dataframe(b, name_col="name", parent_col="parent", path_col="path", attr_dict={"age": "person age"})
+         path name parent  person age
+    0    /a/b    b      a          65
+    1  /a/b/d    d      b          40
+    2  /a/b/e    e      b          35
+
+    Args:
+        tree (Node): tree to be exported
+        path_col (str): column name for `node.path_name`, optional
+        name_col (str): column name for `node.node_name`, defaults to 'name'
+        parent_col (str): column name for `node.parent.node_name`, optional
+        attr_dict (dict): dictionary mapping node attributes to column name,
+            key: node attributes, value: corresponding column in dataframe, optional
+        all_attrs (bool): indicator whether to retrieve all `Node` attributes
+        max_depth (int): maximum depth to export tree, optional
+        skip_depth (int): number of initial depth to skip, optional
+        leaf_only (bool): indicator to retrieve only information from leaf nodes
+
+    Returns:
+        (pd.DataFrame)
+    """
+    tree = tree.copy()
+    data_list = []
+
+    def recursive_append(node):
+        if (
+            (not max_depth or node.depth <= max_depth)
+            and (not skip_depth or node.depth > skip_depth)
+            and (not leaf_only or node.is_leaf)
+        ):
+            data_child = {}
+            if path_col:
+                data_child[path_col] = node.path_name
+            if name_col:
+                data_child[name_col] = node.node_name
+            if parent_col:
+                parent_name = None
+                if node.parent:
+                    parent_name = node.parent.node_name
+                data_child[parent_col] = parent_name
+
+            if all_attrs:
+                data_child.update(
+                    node.describe(exclude_attributes=["name"], exclude_prefix="_")
+                )
+            else:
+                for k, v in attr_dict.items():
+                    data_child[v] = node.get_attr(k)
+            data_list.append(data_child)
+        for _node in node.children:
+            recursive_append(_node)
+
+    recursive_append(tree)
+    return pd.DataFrame(data_list)
+
+
 def tree_to_dot(
     tree: Node,
     directed: bool = True,
+    rankdir: str = "TB",
     bgcolor: str = None,
-    fillcolor: str = None,
+    node_colour: str = None,
+    edge_colour: str = None,
     node_attr: str = None,
 ):
     r"""Export tree to image.
-    Note that node names must be unique.
+    Posible node attributes include style, fillcolor, shape.
 
     >>> from bigtree import Node, tree_to_dot
     >>> root = Node("a", age=90)
@@ -593,14 +594,16 @@ def tree_to_dot(
     Export to string
 
     >>> graph.to_string()
-    'strict digraph G {\na [label=a];\nb [label=b];\nb -> a;\nd [label=d];\nd -> b;\ne [label=e];\ne -> b;\nc [label=c];\nc -> a;\n}\n'
+    'strict digraph G {\nrankdir=TB;\na0 [label=a];\nb0 [label=b];\na0 -> b0;\nd0 [label=d];\nb0 -> d0;\ne0 [label=e];\nb0 -> e0;\nc0 [label=c];\na0 -> c0;\n}\n'
 
     Args:
         tree (Node): tree to be exported
         directed (bool): indicator whether graph should be directed or undirected, defaults to True
+        rankdir (str): set direction of graph layout, defaults to 'TB', can be 'BT, 'LR', 'RL'
         bgcolor (str): background color of image, defaults to None
-        fillcolor (str): fill colour of nodes, defaults to None
-        node_attr (str): node attribute for style, overrides fillcolor, defaults to None
+        node_colour (str): fill colour of nodes, defaults to None
+        edge_colour (str): colour of edges, defaults to None
+        node_attr (str): node attribute for style, overrides node_colour, defaults to None
 
     Returns:
         (pydot.Dot)
@@ -609,7 +612,7 @@ def tree_to_dot(
         import pydot
     except ImportError:  # pragma: no cover
         raise ImportError(
-            "pydot not available. Please perform a `pip install bigtree[graph]` to install required dependencies"
+            "pydot not available. Please perform a\n\npip install 'bigtree[image]'\n\nto install required dependencies"
         )
 
     if not isinstance(tree, Node):
@@ -621,154 +624,45 @@ def tree_to_dot(
     else:
         graph_style = dict()
 
-    if fillcolor:
-        node_style = dict(style="filled", fillcolor=fillcolor)
+    if node_colour:
+        node_style = dict(style="filled", fillcolor=node_colour)
     else:
         node_style = dict()
 
+    if edge_colour:
+        edge_style = dict(color=edge_colour)
+    else:
+        edge_style = dict()
+
     tree = tree.copy()
 
     if directed:
-        _graph = pydot.Dot(graph_type="digraph", strict=True, **graph_style)
+        _graph = pydot.Dot(
+            graph_type="digraph", strict=True, rankdir=rankdir, **graph_style
+        )
     else:
-        _graph = pydot.Dot(graph_type="graph", strict=True, **graph_style)
+        _graph = pydot.Dot(
+            graph_type="graph", strict=True, rankdir=rankdir, **graph_style
+        )
+
+    name_dict = collections.defaultdict(list)
 
     def recursive_create_node_and_edges(parent_name, child_node):
-        child_name = child_node.node_name
+        child_label = child_node.node_name
+        if child_node.path_name not in name_dict[child_label]:  # pragma: no cover
+            name_dict[child_label].append(child_node.path_name)
+        child_name = child_label + str(
+            name_dict[child_label].index(child_node.path_name)
+        )
         if node_attr and child_node.get_attr(node_attr):
             node_style.update(child_node.get_attr(node_attr))
-        node = pydot.Node(name=child_name, label=child_name, **node_style)
+        node = pydot.Node(name=child_name, label=child_label, **node_style)
         _graph.add_node(node)
         if parent_name is not None:
-            edge = pydot.Edge(child_name, parent_name)
+            edge = pydot.Edge(parent_name, child_name, **edge_style)
             _graph.add_edge(edge)
         for child in child_node.children:
             recursive_create_node_and_edges(child_name, child)
 
     recursive_create_node_and_edges(None, tree.root)
     return _graph
-
-
-def dag_to_dot(
-    tree: DAGNode,
-    bgcolor: str = None,
-    fillcolor: str = None,
-    node_attr: str = None,
-):
-    r"""Export DAG tree to image.
-    Note that node names must be unique.
-
-    >>> from bigtree import DAGNode, dag_to_dot
-    >>> a = DAGNode("a", step=1)
-    >>> b = DAGNode("b", step=1)
-    >>> c = DAGNode("c", step=2, parents=[a, b])
-    >>> d = DAGNode("d", step=2, parents=[a, c])
-    >>> e = DAGNode("e", step=3, parents=[d])
-    >>> dag_graph = dag_to_dot(a)
-
-    Export to image, dot file, etc.
-
-    >>> dag_graph.write_png("tree_dag.png")
-    >>> dag_graph.write_dot("tree_dag.dot")
-
-    Export to string
-
-    >>> dag_graph.to_string()
-    'strict digraph G {\na [label=a];\nc [label=c];\na -> c;\nd [label=d];\na -> d;\nc [label=c];\na [label=a];\na -> c;\nb [label=b];\nb -> c;\nd [label=d];\nc -> d;\nd [label=d];\na [label=a];\na -> d;\nc [label=c];\nc -> d;\ne [label=e];\nd -> e;\ne [label=e];\nd [label=d];\nd -> e;\nb [label=b];\nc [label=c];\nb -> c;\n}\n'
-
-    Args:
-        tree (DAGNode): tree to be exported
-        bgcolor (str): background color of image, defaults to None
-        fillcolor (str): fill colour of nodes, defaults to None
-        node_attr (str): node attribute for style, overrides fillcolor, defaults to None
-
-    Returns:
-        (pydot.Dot)
-    """
-    try:
-        import pydot
-    except ImportError:  # pragma: no cover
-        raise ImportError(
-            "pydot not available. Please perform a `pip install bigtree[graph]` to install required dependencies"
-        )
-
-    if not isinstance(tree, DAGNode):
-        raise ValueError("Tree should be of type `DAGNode`, or inherit from `DAGNode`")
-
-    # Get style
-    if bgcolor:
-        graph_style = dict(bgcolor=bgcolor)
-    else:
-        graph_style = dict()
-
-    if fillcolor:
-        node_style = dict(style="filled", fillcolor=fillcolor)
-    else:
-        node_style = dict()
-
-    tree = tree.copy()
-
-    _graph = pydot.Dot(graph_type="digraph", strict=True, **graph_style)
-    visited_nodes = set()
-
-    def recursive_create_node_and_edges(
-        node: DAGNode, node_from_name: str, direction: int
-    ):
-        node = node.copy()
-        node_name = node.node_name
-        if node_name not in visited_nodes:
-            visited_nodes.add(node_name)
-            if node_attr and node.get_attr(node_attr):
-                node_style.update(node.get_attr(node_attr))
-            pydot_node = pydot.Node(name=node_name, label=node_name, **node_style)
-            _graph.add_node(pydot_node)
-
-            # Parse upwards
-            for parent in node.parents:
-                parent_name = parent.node_name
-                pydot_parent_node = pydot.Node(
-                    name=parent_name, label=parent_name, **node_style
-                )
-                edge = pydot.Edge(parent_name, node_name)
-                _graph.add_node(pydot_parent_node)
-                _graph.add_edge(edge)
-
-            # Parse downwards
-            for child in node.children:
-                child_name = child.node_name
-                pydot_child_node = pydot.Node(
-                    name=child_name, label=child_name, **node_style
-                )
-                edge = pydot.Edge(node_name, child_name)
-                _graph.add_node(pydot_child_node)
-                _graph.add_edge(edge)
-
-            # Came from parent
-            if direction == 1:
-                children = list(node.children)
-                parents = list(node.parents)
-                if node_from_name is not None:
-                    parents = [
-                        parent
-                        for parent in parents
-                        if parent.node_name != node_from_name
-                    ]
-                for child in children:
-                    recursive_create_node_and_edges(child, node_name, 1)
-                for parent in parents:
-                    recursive_create_node_and_edges(parent, node_name, 0)
-
-            # Came from child
-            else:
-                children = list(node.children)
-                parents = list(node.parents)
-                children = [
-                    child for child in children if child.node_name != node_from_name
-                ]
-                for child in children:
-                    recursive_create_node_and_edges(child, node_name, 0)
-                for parent in parents:
-                    recursive_create_node_and_edges(parent, node_name, 1)
-
-    recursive_create_node_and_edges(tree, None, 1)
-    return _graph
