@@ -74,6 +74,38 @@ def tree_node():
     return a
 
 
+@pytest.fixture
+def tree_node_duplicate_names():
+    """
+    Tree should have structure
+    a (age=90)
+    |-- a (age=65)
+    |   |-- a (age=40)
+    |   +-- b (age=35)
+    |       |-- a (age=10)
+    |       +-- b (age=6)
+    +-- b (age=60)
+        +-- a (age=38)
+    """
+    a = Node("a", age=90)
+    b = Node("a", age=65)
+    c = Node("b", age=60)
+    d = Node("a", age=40)
+    e = Node("b", age=35)
+    f = Node("a", age=38)
+    g = Node("a", age=10)
+    h = Node("b", age=6)
+
+    b.parent = a
+    c.parent = a
+    d.parent = b
+    e.parent = b
+    f.parent = c
+    g.parent = e
+    h.parent = e
+    return a
+
+
 @pytest.fixture
 def tree_node2():
     """
@@ -175,14 +207,14 @@ def tree_node_style():
 
 @pytest.fixture
 def dag_node():
-    a = DAGNode("a")
-    b = DAGNode("b")
-    c = DAGNode("c")
-    d = DAGNode("d")
-    e = DAGNode("e")
-    f = DAGNode("f")
-    g = DAGNode("g")
-    h = DAGNode("h")
+    a = DAGNode("a", age=90)
+    b = DAGNode("b", age=65)
+    c = DAGNode("c", age=60)
+    d = DAGNode("d", age=40)
+    e = DAGNode("e", age=35)
+    f = DAGNode("f", age=38)
+    g = DAGNode("g", age=10)
+    h = DAGNode("h", age=6)
 
     c.parents = [a, b]
     d.parents = [a, c]
@@ -195,14 +227,14 @@ def dag_node():
 
 @pytest.fixture
 def dag_node_child():
-    a = DAGNode("a")
-    b = DAGNode("b")
-    c = DAGNode("c")
-    d = DAGNode("d")
-    e = DAGNode("e")
-    f = DAGNode("f")
-    g = DAGNode("g")
-    h = DAGNode("h")
+    a = DAGNode("a", age=90)
+    b = DAGNode("b", age=65)
+    c = DAGNode("c", age=60)
+    d = DAGNode("d", age=40)
+    e = DAGNode("e", age=35)
+    f = DAGNode("f", age=38)
+    g = DAGNode("g", age=10)
+    h = DAGNode("h", age=6)
 
     c.parents = [a, b]
     d.parents = [a, c]
